<?php

namespace App\Console\Commands\Lesson;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Base\Category;
use App\Repositories\Models\School\Time;
use Illuminate\Console\Command;
use Illuminate\Support\Str;

/**
 * Class PresenterCommand
 * @package Prettus\Repository\Generators\Commands
 * @author Anderson Andrade <contato@andersonandra.de>
 */
class InitDataCommand extends Command
{
    /**
     * The name of command.
     *
     * @var string
     */
    protected $name = 'lesson:init:data';
    /**
     * The description of command.
     *
     * @var string
     */
    protected $description = 'init data.';
    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'lab';

    /**
     * Execute the command.
     *
     * @return void
     * @see fire()
     */
    public function handle()
    {
//        $this->initTime();

        $this->initCategory();

        $this->line('ok');
    }

    public function initCategory()
    {
        Category::query()->truncate();
        Category::query()->create([
            'name' => '课程类型',
            'type' => '1',
            'key' => 'du2r3YxK',
        ]);

        Category::query()->create([
            'name' => '项目类型',
            'type' => '1',
            'key' => Str::random(8),
        ]);
    }

    /**
     * 初始化时间段
     * @return void
     */
    public function initTime()
    {
        Time::query()->truncate();

        Time::query()->create([
            'name' => '1-2',
            'section' => '1-2',
            'start_time' => '08:30',
            'end_time' => '10:00',
            'type' => 1,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->create([
            'name' => '3-4',
            'section' => '3-4',
            'start_time' => '10:20',
            'end_time' => '11:50',
            'type' => 1,
            'status' => ModelStatusEnum::OK,
        ]);


        Time::query()->create([
            'name' => '5-6',
            'section' => '5-6',
            'start_time' => '14:30',
            'end_time' => '16:00',
            'type' => 3,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->create([
            'name' => '7-8',
            'section' => '7-8',
            'start_time' => '16:20',
            'end_time' => '17:50',
            'type' => 3,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->create([
            'name' => '9-11',
            'section' => '9-11',
            'start_time' => '19:00',
            'end_time' => '20:50',
            'type' => 5,
            'status' => ModelStatusEnum::OK,
        ]);
    }
}
