<?php

namespace App\Exports;

use App\Repositories\Models\Base\CategorySetting;
use App\Repositories\Models\Model;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithColumnWidths;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;


class DemoExport implements FromQuery, WithMapping, WithHeadings, ShouldAutoSize, WithColumnWidths, WithStyles
{
    use Exportable;

    const Name = "证书列表";
    const BaseFields = [
        [
            'name' => '序号',
            'width' => 8,
        ],
        [
            'name' => '名称',
            'width' => 30,
            'field' => 'name'
        ],
        [
            'name' => '编号',
            'width' => 15,
            'field' => 'no'
        ],
    ];
    protected $rowNums = 0;
    protected $ids = [];
    protected $lastC = 'A';
    protected $fields = [];

    public function __construct($ids, $field_ids = [])
    {
        $this->ids = $ids;
        $fields = [];
        if (!count($field_ids)) {
            $fields = self::BaseFields;
        } else {
            foreach ($field_ids as $field_id) {
                $fields[] = self::BaseFields[$field_id];
            }
        }
        $this->fields = $fields;
    }

    public function query()
    {
        $ids = $this->ids;
        return Model::query()->with(['company'])->whereIn('id', $ids)->orderByDesc('id');
    }

    public function map($row): array
    {
        $row = $row->toArray();

        $this->rowNums++;
        $data = [];
        foreach ($this->fields as $k => $item) {
            $field = $item['name'];
            if (isset($item['field']) && isset($row[$item['field']])) {
                $data[$k] = $row[$item['field']];
                continue;
            }

            if ($field == '序号') $data[$k] = $this->rowNums;
            if ($field == '证书所属机构') $data[$k] = isset($row['company']['name']) ? $row['company']['name'] : '';

            if ($field == '行业分类') {
                $data[$k] = arr2str(CategorySetting::byIdsGetName($row['hy_ids']), '、');
            }
        }
        return $data;
    }


    public function headings(): array
    {
        $room_name = self::Name;
        $data[] = [$room_name];

        $data[] = array_column($this->fields, 'name');
        return $data;
    }

    public function headingRow(): int
    {
        return 2;
    }

    public function columnWidths(): array
    {
        $i = 65;
        $data = [];
        foreach ($this->fields as $k => $field) {
            $s = intval($k / 26);

            if (!$s) $key = chr($i + $k);
            if ($s > 0) {
                $y = intval($k % 26);
                $key = chr($s + $i - 1);
                $key .= chr($y + $i);
            }
            $data["{$key}"] = $field['width'];
            $this->lastC = $key;
        }
        return $data;
    }

    public function styles(Worksheet $sheet)
    {
        $last = $this->lastC;
        $cellRange = "A1:{$last}1";
        $sheet->getStyle($cellRange)->getFont()->setSize(12);

        $sheet->getDefaultRowDimension()->setRowHeight(40);//设置行高

        // 文字居中
        $lastrow = $sheet->getHighestRow();
        $sheet->getStyle("A1:{$last}" . $lastrow)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);//垂直居中
        $sheet->getStyle("A1:{$last}" . $lastrow)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle("A1:{$last}" . $lastrow)->getAlignment()->setWrapText(true);

        $sheet->mergeCells("A1:{$last}1"); //合并
        $sheet->getStyle("A1:{$last}1")->getFont()->setSize(16);
    }


}

