<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Services\Base\BannerService;
use Carbon\Carbon;
use Illuminate\Http\Request;

/**
 * Banner
 */
class BannerController extends Controller
{
    /**
     * @var BannerService
     */
    private $bannerService;

    /**
     * BannerController constructor.
     *
     * @param BannerService $bannerService
     */
    public function __construct(BannerService $bannerService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->bannerService = $bannerService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $banners = $this->bannerService->handleList($request);
        return $this->response->success($banners);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
            'cover' => 'required|string',
            'type' => 'required|integer',
            'click_type' => 'required|integer',
            'click_body' => 'nullable|json',
            'start_time' => 'nullable|date',
            'end_time' => 'nullable|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [
            'name' => '名称',
            'cover' => '路径',
            'sort' => '排序',
            'type' => '类型',
            'click_type' => '类型',
            'click_body' => '扩展字段',
            'start_time' => '开始时间',
            'end_time' => '结束时间',
            'status' => '状态',
        ]);

        if (empty($data['start_time'])) $data['start_time'] = Carbon::now()->toDateTimeString();
        if (empty($data['end_time'])) $data['end_time'] = Carbon::now()->addYears(10)->toDateTimeString();

        $banner = $this->bannerService->handleStore($data);
        return $this->response->created($banner, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $banner = $this->bannerService->handleProfile($request->get('id'));
        return $this->response->success($banner);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'cover' => 'required|string',
            'type' => 'required|integer',
            'click_type' => 'required|integer',
            'click_body' => 'nullable|json',
            'start_time' => 'nullable|date',
            'end_time' => 'nullable|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [
            'name' => '名称',
            'cover' => '路径',
            'sort' => '排序',
            'type' => '类型',
            'click_type' => '类型',
            'click_body' => '扩展字段',
            'start_time' => '开始时间',
            'end_time' => '结束时间',
            'status' => '状态',
        ]);

        if (empty($data['start_time'])) $data['start_time'] = Carbon::now()->toDateTimeString();
        if (empty($data['end_time'])) $data['end_time'] = Carbon::now()->addYears(10)->toDateTimeString();

        $banner = $this->bannerService->handleUpdate($data);
        return $this->response->success($banner, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->bannerService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function lists(Request $request)
    {
        $banners = $this->bannerService->handleAll($request);
        return $this->response->success($banners);
    }
}
