<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Services\Base\CategorySettingService;
use Illuminate\Http\Request;

/**
 * 分类配置
 */
class CategorySettingController extends Controller
{
    /**
     * @var CategorySettingService
     */
    private $categorySettingService;

    /**
     * CategorySettingController constructor.
     *
     * @param CategorySettingService $categorySettingService
     */
    public function __construct(CategorySettingService $categorySettingService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->categorySettingService = $categorySettingService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $categorySettings = $this->categorySettingService->handleList($request);
        return $this->response->success($categorySettings);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $categorySetting = $this->categorySettingService->handleStore($data);
        return $this->response->created($categorySetting, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $categorySetting = $this->categorySettingService->handleProfile($request->get('id'));
        return $this->response->success($categorySetting);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $categorySetting = $this->categorySettingService->handleUpdate($data);
        return $this->response->success($categorySetting, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->categorySettingService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
