<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Services\Base\CompanyService;
use Illuminate\Http\Request;

/**
 * 商户配置
 */
class CompanyController extends Controller
{
    /**
     * @var CompanyService
     */
    private $companyService;

    /**
     * CompanyController constructor.
     *
     * @param CompanyService $companyService
     */
    public function __construct(CompanyService $companyService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->companyService = $companyService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $companys = $this->companyService->handleList($request);
        return $this->response->success($companys);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $company = $this->companyService->handleStore($data);
        return $this->response->created($company, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $company = $this->companyService->handleProfile($request->get('id'));
        return $this->response->success($company);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $company = $this->companyService->handleUpdate($data);
        return $this->response->success($company, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->companyService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
