<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Services\Base\DepartmentService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;

/**
 * 部门管理
 *
 * @package namespace App\Http\Controllers;
 */
class DepartmentController extends Controller
{
    protected $service;

    public function __construct(DepartmentService $categoryService)
    {
        parent::__construct();
        $this->service = $categoryService;
    }

    /**
     * 列表
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $data = $this->service->handleList($request);
        return $this->response->success($data);
    }

    /**
     * 新增
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required',
            'parent_id' => 'required|integer',
            'sort' => 'required|integer',
            'status' => 'required|integer'
        ], [
            'name' => '名称',
            'parent_id' => '父 id',
            'sort' => '排序id',
            'status' => '状态'
        ]);

        $model = $this->service->handleStore($data);
        return $this->response->created($model, '创建成功');
    }


    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $model = $this->service->handleProfile($request->get('id'));
        return $this->response->success($model);
    }

    /**
     * 编辑
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required',
            'parent_id' => 'required|integer',
            'sort' => 'required|integer',
            'status' => 'required|integer'
        ], [
            'name' => '名称',
            'parent_id' => '父 id',
            'sort' => '排序id',
            'status' => '状态'
        ]);

        $model = $this->service->handleUpdate($data);
        return $this->response->success($model, '创建成功');
    }

    /**
     * 删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->service->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

    /**
     * 批量删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function batchDelete(Request $request)
    {
        $ids = $this->validateData($request, ['ids' => 'required|array']);
        $re = $this->service->handleBatchDelete($ids);
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

    /**
     * 选项
     * @must
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function selectOptions(Request $request)
    {
        $lists = $this->service->handleSelectOptions($request);
        return $this->response->success($lists);
    }

    /**
     * 获取树
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function tree(Request $request)
    {
        $data = $this->service->handleAll($request);

        return Response::success(toTree($data['list']));
    }
}
