<?php

namespace App\Http\Controllers\Admin\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\ChapterService;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

/**
 * 章节管理
 *
 * @package namespace App\Http\Controllers;
 */
class ChapterController extends Controller
{
    protected $service;

    public function __construct(ChapterService $service)
    {
        parent::__construct();
        $this->service = $service;
    }

    /**
     * 列表
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $this->validate($request, ['course_id' => 'required|integer']);
        $data = $this->service->handleAll($request);
        return $this->response->success($data);
    }

    /**
     * 新增
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'course_id' => 'required|integer',
            'title' => 'required',
            'sort' => 'sometimes|nullable|integer',
            'status' => 'required|integer',
        ], [
            'course_id' => '课程id',
            'title' => '课程名称',
            'sort' => '排序',
            'status' => '状态',
        ]);

        $model = $this->service->handleStore($data);
        return $this->response->created($model, '创建成功');
    }


    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $model = $this->service->handleProfile($request->get('id'));
        return $this->response->success($model);
    }

    /**
     * 编辑
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'course_id' => 'required|integer',
            'title' => 'required',
            'sort' => 'sometimes|nullable|integer',
            'status' => 'required|integer',
        ], [
            'course_id' => '课程id',
            'title' => '课程名称',
            'sort' => '排序',
            'status' => '状态',
        ]);

        $model = $this->service->handleUpdate($data);
        return $this->response->success($model, '创建成功');
    }

    /**
     * 删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer', 'course_id' => 'required|integer']);
        $re = $this->service->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

    /**
     * 批量删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function batchDelete(Request $request)
    {
        $ids = $this->validateData($request, ['ids' => 'required|array']);
        $re = $this->service->handleBatchDelete($ids);
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

}
