<?php

namespace App\Http\Controllers\Admin\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\CommentService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;

/**
 * 评论管理
 *
 * @package namespace App\Http\Controllers;
 */
class CommentController extends Controller
{
    protected $service;

    public function __construct(CommentService $service)
    {
        parent::__construct();
        $this->service = $service;
    }

    /**
     * 列表
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $data = $this->service->handleAll($request);
        return $this->response->success($data);
    }

    /**
     * 新增
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'course_id' => 'required|integer',
            'course_video_id' => 'required|integer',
            'points' => 'required|integer',
            'content' => 'required',
        ], [
            'course_id' => '课程id',
            'course_video_id' => '视频 id',
            'points' => '分值',
            'content' => '内容',
        ]);
        $data['user_id'] = login_admin_id();
        $model = $this->service->handleStore($data);
        return $this->response->created($model, '创建成功');
    }


    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $model = $this->service->handleProfile($request->get('id'));
        return $this->response->success($model);
    }

    /**
     * 删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->service->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

    /**
     * 批量删除
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function batchDelete(Request $request)
    {
        $ids = $this->validateData($request, ['ids' => 'required|array']);
        $re = $this->service->handleBatchDelete($ids);
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
