<?php

namespace App\Http\Controllers\Admin\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\WatchRecordService;
use Illuminate\Http\Request;

/**
 * 观看记录
 */
class WatchRecordController extends Controller
{
    /**
     * @var WatchRecordService
     */
    private $watchRecordService;

    /**
     * WatchRecordController constructor.
     *
     * @param WatchRecordService $watchRecordService
     */
    public function __construct(WatchRecordService $watchRecordService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->watchRecordService = $watchRecordService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $watchRecords = $this->watchRecordService->handleList($request);
        return $this->response->success($watchRecords);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $watchRecord = $this->watchRecordService->handleStore($data);
        return $this->response->created($watchRecord, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $watchRecord = $this->watchRecordService->handleProfile($request->get('id'));
        return $this->response->success($watchRecord);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $watchRecord = $this->watchRecordService->handleUpdate($data);
        return $this->response->success($watchRecord, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->watchRecordService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
