<?php

namespace App\Http\Controllers\Admin\Info;

use App\Http\Controllers\Controller;
use App\Services\Info\InformationTypeService;
use Illuminate\Http\Request;

/**
 * 新闻咨询类型
 */
class InformationTypeController extends Controller
{
    /**
     * @var InformationTypeService
     */
    private $informationTypeService;

    /**
     * InformationTypeController constructor.
     *
     * @param InformationTypeService $informationTypeService
     */
    public function __construct(InformationTypeService $informationTypeService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->informationTypeService = $informationTypeService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $informationTypes = $this->informationTypeService->handleList($request);
        return $this->response->success($informationTypes);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
        ], []);
        $informationType = $this->informationTypeService->handleStore($data);
        return $this->response->created($informationType, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $informationType = $this->informationTypeService->handleProfile($request->get('id'));
        return $this->response->success($informationType);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
        ], []);
        $informationType = $this->informationTypeService->handleUpdate($data);
        return $this->response->success($informationType, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->informationTypeService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
