<?php

namespace App\Http\Controllers\Admin\Info;

use App\Http\Controllers\Controller;
use App\Services\Info\NewsService;
use Illuminate\Http\Request;

/**
 * 新闻
 */
class NewsController extends Controller
{
    /**
     * @var NewsService
     */
    private $newsService;

    /**
     * NewsController constructor.
     *
     * @param NewsService $newsService
     */
    public function __construct(NewsService $newsService)
    {
        parent::__construct();
        $this->middleware('checkUserPermission');

        $this->newsService = $newsService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $news = $this->newsService->handleList($request);
        return $this->response->success($news);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|string|max:200',
            'description' => 'sometimes|nullable|string|max:500',
            'cover_path' => 'sometimes|nullable',
            'body' => 'required',
            'release_time' => 'required|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [], [
            'name' => '新闻标题',
            'description' => '新闻摘要',
            'cover_path' => '新闻封面图',
            'body' => '新闻内容',
            'release_time' => '发布时间',
        ]);
        $news = $this->newsService->handleStore($request);
        return $this->response->created($news, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $news = $this->newsService->handleProfile($request->get('id'));
        return $this->response->success($news);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $this->validate($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'description' => 'sometimes|nullable|string|max:500',
            'cover_path' => 'sometimes|nullable',
            'body' => 'required',
            'release_time' => 'required|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [], [
            'name' => '新闻标题',
            'description' => '新闻摘要',
            'cover_path' => '新闻封面图',
            'body' => '新闻内容',
            'release_time' => '发布时间',
        ]);
        $news = $this->newsService->handleUpdate($request);
        return $this->response->success($news, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->newsService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
