<?php

namespace App\Http\Controllers\Admin\Info;

use App\Http\Controllers\Controller;
use App\Services\Info\NoticeService;
use Illuminate\Http\Request;

/**
 * 通知公告
 */
class NoticeController extends Controller
{
    /**
     * @var NoticeService
     */
    private $noticeService;

    /**
     * NoticeController constructor.
     *
     * @param NoticeService $noticeService
     */
    public function __construct(NoticeService $noticeService)
    {
        parent::__construct();
        $this->middleware('checkUserPermission');

        $this->noticeService = $noticeService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $notices = $this->noticeService->handleList($request);
        return $this->response->success($notices);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|string|max:200',
            'description' => 'sometimes|nullable|string|max:500',
            'body' => 'required',
            'release_time' => 'required|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [], [
            'name' => '公告标题',
            'description' => '公告摘要',
            'body' => '公告内容',
            'release_time' => '发布时间',
        ]);
        $notice = $this->noticeService->handleStore($request);
        return $this->response->created($notice, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $notice = $this->noticeService->handleProfile($request->get('id'));
        return $this->response->success($notice);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $this->validate($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'description' => 'sometimes|nullable|string|max:500',
            'body' => 'required',
            'release_time' => 'required|date',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], [], [
            'name' => '公告标题',
            'description' => '公告摘要',
            'body' => '公告内容',
            'release_time' => '发布时间',
        ]);
        $notice = $this->noticeService->handleUpdate($request);
        return $this->response->success($notice, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->noticeService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
