<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Base\Resource;
use App\Repositories\Models\Course\Attach;
use App\Services\Course\AttachService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Jiannei\Response\Laravel\Support\Facades\Response;

/**
 * 附件管理
 *
 * @package namespace App\Http\Controllers;
 */
class AttachController extends Controller
{
    protected $service;

    public function __construct(AttachService $service)
    {
        parent::__construct();
        $this->service = $service;
    }

    /**
     * 列表
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $this->validateData($request, ['course_id' => 'required|integer', 'course_video_id' => 'nullables|integer']);
        $data = $this->service->handleList($request);
        return $this->response->success($data);
    }

    /**
     * 下载文件
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Symfony\Component\HttpFoundation\BinaryFileResponse
     * @throws \Illuminate\Validation\ValidationException
     */
    public function download(Request $request)
    {
        $data = $this->validateData($request, ['course_id' => 'required|integer', 'course_video_id' => 'required|integer', 'id' => 'required|integer']);

        $attach = Attach::query()->where('course_id', $data['course_id'])->where('course_video_id', $data['course_video_id'])->where('id', $data['id'])->where('status', ModelStatusEnum::OK)->first();
        if ($attach) {
            $attach->download_times++;
            $attach->save();
            $resource = Resource::query()->find($attach->path);

            if (!Storage::disk($resource->disk)->exists($resource->path)) {
                return Response::fail('找不到文件');
            }

            return response()->download(Storage::disk($resource->disk)->path($resource->path), $resource->name, [
                'Access-Control-Allow-Origin' => '*',
                'Access-Control-Allow-Methods' => '*',
                'Access-Control-Allow-Headers' => 'Content-Type, Authorization, X-Requested-With',
                'Access-Control-Expose-Headers' => 'Content-Disposition',
                'Content-type' => 'application/octet-stream',
                'Content-Disposition' => 'attachment; filename=' . $resource->name,
            ]);
        }
        return $this->error('找不到该文件');
    }
}
