<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\CollectService;
use Illuminate\Http\Request;

/**
 * 收藏
 */
class CollectController extends Controller
{
    /**
     * @var CollectService
     */
    private $service;

    /**
     * CollectController constructor.
     *
     * @param CollectService $collectService
     */
    public function __construct(CollectService $service)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->service = $service;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $lists = $this->service->handleList($request);
        return $this->response->success($lists);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'course_id' => 'required|integer',
        ], [
            'course_id' => '课程id'
        ]);
        $data['user_id'] = login_user_id();
        $model = $this->service->handleStore($data);
        return $this->response->created($model, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $model = $this->service->handleProfile($request->get('id'));
        return $this->response->success($model);
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->service->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }

}
