<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\CommentService;
use Illuminate\Http\Request;

/**
 * 评论管理
 * @package namespace App\Http\Controllers;
 */
class CommentController extends Controller
{
    public function __construct(CommentService $service)
    {
        parent::__construct();
        $this->service = $service;
    }

    public function index(Request $request)
    {
        $this->validateData($request, ['course_id' => 'required|integer', 'course_video_id' => 'sometimes|nullable|integer']);
        $data = $this->service->handleList($request);
        return $this->response->success($data);
    }

    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'course_id' => 'required|integer',
            'course_video_id' => 'required|integer',
//            'points' => 'required|integer',
            'content' => 'required',
        ], [
            'course_id' => '课程id',
            'course_video_id' => '视频 id',
//            'points' => '分值',
            'content' => '内容',
        ]);
        $data['user_id'] = login_user_id();
        $model = $this->service->handleStore($data);
        return $this->response->created($model, '创建成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->service->handleUserDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
