<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Models\Course\Course;
use App\Repositories\Models\Course\Subscribe;
use App\Services\Course\CourseService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Contracts\Repositories\Course\CourseRepository;
use App\Repositories\Validators\Course\CourseValidator;

/**
 *  课程管理
 * @package namespace App\Http\Controllers;
 */
class CourseController extends Controller
{

    protected $service;

    /**
     * CoursesController constructor.
     *
     * @param CourseRepository $repository
     * @param CourseValidator $validator
     */
    public function __construct(CourseService $service)
    {
        parent::__construct();
        $this->service = $service;
    }

    public function index(Request $request)
    {
        $courses = $this->service->handleList($request);
        return Response::success($courses);
    }

    /**
     * 详情
     * Author: Mead
     */
    public function show(Request $request)
    {
        $this->validateData($request, [
            'id' => 'required|integer'
        ]);
        $id = $request->get('id');
        $course = $this->service->handleProfile($id);
//        $directory = [];

//        $data = Chapter::query()->where('course_id', $course['id'])->where('status', ModelStatusEnum::OK)->orderByDesc('sort')->get();
//        foreach ($data as $d) {
//            $directory[] = [
//                'id' => $d['id'],
//                'title' => $d['title'],
//                'children' => $d->videos()->where('status', ModelStatusEnum::OK)->where('published_at', '<', Carbon::now())->orderByDesc('sort')->get(['id', 'title', 'duration', 'short_description'])->append(['duration_text', "progress"])
//            ];
//        }

//        $comments = $course->comments()->with(['user'])->limit(self::PAGE_NUM)->orderByDesc('id')->get();
//
//        $attaches = $course->attaches()->with(['path_resource'])->where('status', ModelStatusEnum::OK)->get(['name', 'id', 'path', 'download_times']);
//
//        $subscribe = $course->subscribe()->where('user_id', login_user_id())->first();

//        $course = $this->repository->parserResult($course);

//        $watch_record_video_id = UserVideoWatchRecord::query()->where('user_id', login_user_id())->where('course_id', $id)->orderByDesc('watched_at')->value('video_id');
        return $this->response->success($course);
    }

    /**
     * 订阅课程
     * @param Request $request
     * Author: Mead
     */
    public function subscribe(Request $request)
    {
        $this->validateData($request, [
            'course_id' => 'required|integer'
        ], [
            'course_id' => '课程id'
        ]);
        $course_id = $request->get('course_id');
        $user_id = login_user_id();
        if (Subscribe::query()->where('course_id', $course_id)->where('user_id', $user_id)->exists()) {
            abort(ResponseCodeEnum::SERVICE_OPERATION_ERROR, '请勿重复操作');
        }
        Subscribe::query()->create(['course_id' => $course_id, 'user_id' => $user_id]);
        Course::query()->where('id', $course_id)->increment('user_count');
        return $this->response->ok('订阅成功');
    }

}
