<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\NodeService;
use Illuminate\Http\Request;

/**
 * 笔记管理
 */
class NodeController extends Controller
{
    /**
     * @var NodeService
     */
    private $nodeService;

    /**
     * NodeController constructor.
     *
     * @param NodeService $nodeService
     */
    public function __construct(NodeService $nodeService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->nodeService = $nodeService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $nodes = $this->nodeService->handleList($request);
        return $this->response->success($nodes);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'course_id' => 'required|integer',
            'course_video_id' => 'required|integer',
            'title' => 'required',
            'body' => 'required',
        ], [
            'course_id' => '课程 id',
            'course_video_id' => '视频 id',
            'title' => '笔记标题',
            'body' => '笔记内容',
        ]);
        $data['user_id'] = login_user_id();
        $node = $this->nodeService->handleStore($data);
        return $this->response->created($node, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $node = $this->nodeService->handleProfile($request->get('id'));
        return $this->response->success($node);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'course_id' => 'required|integer',
            'course_video_id' => 'required|integer',
            'title' => 'required',
            'body' => 'required',
        ], [
            'course_id' => '课程 id',
            'course_video_id' => '视频 id',
            'title' => '笔记标题',
            'body' => '笔记内容',
        ]);
        $node = $this->nodeService->handleUpdate($data);
        return $this->response->success($node, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->nodeService->handleUserDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
