<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Services\Course\SubscribeService;
use Illuminate\Http\Request;

/**
 * 课程订阅
 */
class SubscribeController extends Controller
{
    /**
     * @var SubscribeService
     */
    private $subscribeService;

    /**
     * SubscribeController constructor.
     *
     * @param SubscribeService $subscribeService
     */
    public function __construct(SubscribeService $subscribeService)
    {
        parent::__construct();
//        $this->middleware('checkUserPermission');

        $this->subscribeService = $subscribeService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $subscribes = $this->subscribeService->handleList($request);
        return $this->response->success($subscribes);
    }

    /**
     * 新增
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(Request $request)
    {
        $data = $this->validateData($request, [
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $subscribe = $this->subscribeService->handleStore($data);
        return $this->response->created($subscribe, '创建成功');
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $subscribe = $this->subscribeService->handleProfile($request->get('id'));
        return $this->response->success($subscribe);
    }

    /**
     * 更新
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(Request $request)
    {
        $data = $this->validateData($request, [
            'id' => 'required|integer',
            'name' => 'required|string|max:200',
            'sort' => 'required|integer',
            'status' => 'required|integer',
        ], []);
        $subscribe = $this->subscribeService->handleUpdate($data);
        return $this->response->success($subscribe, '更新成功');
    }

    /**
     * 删除
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $re = $this->subscribeService->handleDelete($request->get('id'));
        if ($re) {
            return $this->response->ok('删除成功');
        }
        return $this->response->fail('删除失败');
    }
}
