<?php

namespace App\Http\Controllers\Api\Info;

use App\Http\Controllers\Controller;
use App\Services\Info\NewsService;
use Illuminate\Http\Request;

/**
 * 新闻
 */
class NewsController extends Controller
{
    /**
     * @var NewsService
     */
    private $newsService;

    /**
     * NewsController constructor.
     *
     * @param NewsService $newsService
     */
    public function __construct(NewsService $newsService)
    {
        parent::__construct();
        $this->middleware('checkUserPermission');

        $this->newsService = $newsService;
    }

    /**
     * 列表
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function index(Request $request)
    {
        $news = $this->newsService->handleList($request);
        return $this->response->success($news);
    }

    /**
     * 详情
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function show(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $news = $this->newsService->handleProfile($request->get('id'));
        return $this->response->success($news);
    }
}
