<?php

namespace App\Repositories\Criteria\Base;

use App\Repositories\Enums\Base\AdminTypeEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

class RoleCriteria implements CriteriaInterface
{
    /**
     * @var \Illuminate\Http\Request
     */
    protected $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    /**
     * @param $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('nickname')) {
            $model = $model->where('nickname', 'like', '%' . $this->request->get('nickname') . '%');
        }

        if ($this->request->filled('name')) {
            $model = $model->where('name', 'like', $this->request->get('name') . '%');
        }

        if (!$this->request->filled('orderBy')) {
            $model = $model->orderBy('id');
        }

        $admin = login_admin();
        switch ($admin['type']) {
            case AdminTypeEnum::ADMIN:
                $company_id = $admin['company_id'];
                if ($company_id) $model = $model->where('company_id', '=', $company_id);
                break;
        }

        return $model;
    }
}
