<?php

namespace App\Repositories\Criteria\Course;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class CourseAttachCriteria.
 *
 * @package namespace App\Repositories\Criteria;
 */
class AttachCriteria implements CriteriaInterface
{
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status', 0);
            $model = $model->where('status', '=', $status);
        }

        if ($this->request->filled('course_id')) {
            $course_id = $this->request->get('course_id');
            $model = $model->where('course_id', '=', $course_id);
        }

        if ($this->request->filled('course_video_id')) {
            $course_video_id = $this->request->get('course_video_id');
            $model = $model->where('course_video_id', '=', $course_video_id);
        }

        if (!$this->request->filled('orderBy')) {
            $model = $model->orderByDesc('sort')->orderBy('id');
        }

        if (isApi()) {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }
        return $model;
    }
}
