<?php

namespace App\Repositories\Criteria\Course;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class CourseCategoryCriteria.
 *
 * @package namespace App\Repositories\Criteria;
 */
class CategoryCriteria implements CriteriaInterface
{
    /**
     * @var \Illuminate\Http\Request
     */
    protected $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }

    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status', false);
            $model = $model->where('status', '=', $status);
        }

        if ($this->request->filled('category_id')) {
            $category_id = $this->request->get('category_id');
            $model = $model->where('category_id', '=', $category_id);
        }

        if ($this->request->filled('parent_id')) {
            $parent_id = $this->request->get('parent_id');
            $model = $model->where('parent_id', '=', $parent_id);
        }

        if (!$this->request->filled('orderBy')) {
            $model = $model->orderByDesc('sort')->orderByDesc('id');
        }

        if (isApi()) {
            $model = $model->where('status', ModelStatusEnum::OK);
        }
        return $model;
    }
}
