<?php

namespace App\Repositories\Criteria\Exam;

use App\Repositories\Enums\PermissionEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class PaperResultCriteria.
 *
 * @package namespace App\Repositories\Criteria\Exam;
 */
class PaperResultCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        if ($this->request->filled('assign_admin_id')) {
            $assign_admin_id = $this->request->get('assign_admin_id');
            $model = $model->where('assign_admin_id', '=', $assign_admin_id);
        }

        if ($this->request->filled('polling_admin_id')) {
            $polling_admin_id = $this->request->get('polling_admin_id');
            $model = $model->where('polling_admin_id', '=', $polling_admin_id);
        }

        if ($this->request->filled('is_answer')) {
            $is_answer = $this->request->get('is_answer');
            $model = $model->where('is_answer', '=', $is_answer);
        }

        if ($this->request->filled('is_exist_danger')) {
            $is_exist_danger = $this->request->get('is_exist_danger');
            $model = $model->where('is_exist_danger', '=', $is_exist_danger);
        }


        if ($this->request->filled('paper_name')) {
            $paper_name = $this->request->get('paper_name');
            $model = $model->whereHas('paper', function ($query) use ($paper_name) {
                return $query->where('name', 'like', "%{$paper_name}%");
            });
        }

        if ($this->request->filled('assign_admin_name')) {
            $assign_admin_name = $this->request->get('assign_admin_name');
            $model = $model->whereHas('assign_admin', function ($query) use ($assign_admin_name) {
                return $query->where('name', 'like', "%{$assign_admin_name}%");
            });
        }

        if ($this->request->filled('polling_admin_name')) {
            $polling_admin_name = $this->request->get('polling_admin_name');
            $model = $model->whereHas('polling_admin', function ($query) use ($polling_admin_name) {
                return $query->where('name', 'like', "%{$polling_admin_name}%");
            });
        }

        $model = $model->orderByDesc('id');

        $admin = login_admin();
        $source = getControllerAndFunction();
        $controller = $source['controller'];
        $method = $source['method'];

        if (!$admin->can(PermissionEnum::model_paperResult_all) && !in_array($method, ['show'])) {
            //班长
            if ($admin->can(PermissionEnum::model_paperResult_monitor)) {
                $model = $model->where('assign_admin_id', '=', $admin['id']);
            }
            //我的
            if ($admin->can(PermissionEnum::model_paperResult_me)) {
                $model = $model->where('polling_admin_id', '=', $admin['id']);
            }
        }

        return $model;
    }
}
