<?php

namespace App\Repositories\Criteria\School;

use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class LessonCriteria.
 *
 * @package namespace App\Repositories\Criteria\School;
 */
class LessonTeacherCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {

        if ($this->request->filled('term_id')) {
            $term_id = $this->request->get('term_id');
            $model = $model->where('term_id', '=', $term_id);
        }

        if ($this->request->filled('lesson_name')) {
            $lesson_name = $this->request->get('lesson_name');
            $model = $model->whereHas('lesson', function ($query) use ($lesson_name) {
                return $query->where('name', 'like', "%{$lesson_name}%");
            });
        }

        if ($this->request->filled('teacher_id')) {
            $teacher_id = $this->request->get('teacher_id');
            $model = $model->where('teacher_id', '=', $teacher_id);
        }

        if ($this->request->filled('teacher_name')) {
            $teacher_name = $this->request->get('teacher_name');
            $model = $model->whereHas('teacher', function ($query) use ($teacher_name) {
                return $query->where('name', 'like', "%{$teacher_name}%");
            });
        }

        if ($this->request->filled('grade_name')) {
            $grade_name = $this->request->get('grade_name');
            $model = $model->whereHas('grade', function ($query) use ($grade_name) {
                return $query->where('name', 'like', "%{$grade_name}%");
            });
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->where('term_id', $this->request->header('term-id'));
        $model = $model->orderByDesc('id');

        return $model;
    }
}
