<?php

namespace App\Repositories\Criteria\School;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class TeacherCriteria.
 *
 * @package namespace App\Repositories\Criteria\School;
 */
class TeacherCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('account')) {
            $account = $this->request->get('account');
            $model = $model->where('account', 'like', "%{$account}");
        }

        if ($this->request->filled('department_id')) {
            $department_id = $this->request->get('department_id');
            $model = $model->where('department_id', $department_id);
        }

        if ($this->request->filled('department_ids')) {
            $department_ids = $this->request->get('department_ids');
            $model = $model->whereIn('department_id', $department_ids);
        }

        if ($this->request->filled('ids')) {
            $ids = $this->request->get('ids');
            $model = $model->whereIn('id', $ids);
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status', false);
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if (!$this->request->filled('orderBy')) {
            $model = $model->orderByDesc('id');
        }

        return $model;
    }
}
