<?php

namespace App\Repositories\Eloquent\Base;

use App\Contracts\Repositories\Base\AdminRepository;
use App\Repositories\Models\Base\User;
use Illuminate\Support\Facades\Hash;
use Prettus\Repository\Criteria\RequestCriteria;
use Prettus\Repository\Eloquent\BaseRepository;

class UserRepositoryEloquent extends BaseRepository implements AdminRepository
{
    protected $fieldSearchable = [
        // 'name' => 'like', Default Condition "="
    ];

    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return User::class;
    }

    /**
     * Boot up the repository, pushing criteria.
     *
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function boot()
    {
        $this->pushCriteria(app(RequestCriteria::class));
    }

    /**
     * @return mixed
     */
    public function searchUsersByPage()
    {
        return $this->paginate(request('per_page', 15));
    }

    /**
     * @param $id
     *
     * @return mixed
     */
    public function searchAdminBy($id)
    {
        return $this->find($id);
    }

    public function searchUserBy($id)
    {
        return $this->find($id);
    }

    /**
     * 更新用户登录地址
     * @param $admin_id
     * @param $ip
     * @return \Illuminate\Contracts\Pagination\LengthAwarePaginator|\Illuminate\Support\Collection|mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function updateLoginInfo($user_id, $ip)
    {
        $this->validator = null;
        return $this->update([
            'last_login_time' => date('Y-m-d H:i:s'),
            'last_login_ip' => $ip,
        ], $user_id);
    }

    /**
     * 验证密码是否正确
     * @param $id
     * @param $password
     * @return mixed
     */
    public function byIdConfirmPassword($id, $password)
    {
        $user_password = $this->where('id', $id)->value('password');
        return Hash::check(base64_decode($password), $user_password);
    }
}
