<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Repositories\Models\Base;

use App\Repositories\Models\Model;
use Database\Factories\UserFactory;
use Illuminate\Auth\Authenticatable;
use Illuminate\Contracts\Auth\Access\Authorizable as AuthorizableContract;
use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\DB;
use Laravel\Lumen\Auth\Authorizable;
use Spatie\Permission\Traits\HasRoles;
use Tymon\JWTAuth\Contracts\JWTSubject;

class Admin extends Model implements AuthenticatableContract, AuthorizableContract, JWTSubject
{

    protected $table = 'base_admins';

    use Authenticatable, Authorizable, HasFactory, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    /**
     * The attributes excluded from the model's JSON form.
     *
     * @var array
     */
    protected $hidden = [
        'password',
    ];

    protected $casts = [
        'extra_fields' => 'json'
    ];


    /**
     * 兼容 Laravel 8 的 Factory.
     *
     * @return UserFactory
     */
    protected static function newFactory()
    {
        return UserFactory::new();
    }

    /**
     * Get the identifier that will be stored in the subject claim of the JWT.
     *
     * @return mixed
     */
    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Return a key value array, containing any custom claims to be added to the JWT.
     *
     * @return array
     */
    public function getJWTCustomClaims()
    {
        return ['role' => 'admin'];
    }

    public function getRolesNameAttribute()
    {
        return DB::table(config('permission.table_names.roles'))->select(['id', 'name', 'nickname'])->whereIn('id',
            DB::table(config('permission.table_names.model_has_roles'))->where('model_id', $this->attributes['id'])->pluck('role_id')
        )->get();
    }

    public function department()
    {
        return $this->belongsTo(Department::class)->select(['id', 'name'])->withDefault(['id' => 0, 'name' => '--']);
    }

    public function getHeadimgAttribute($val)
    {
        if (empty($val)) {
            return path_to_url('default/headImg.jpeg');
        }
        return path_to_url($val);
    }


    /**
     * 是否为超级管理员
     * @return bool
     */
    public function isSuperAdmin()
    {
        return in_array($this->attributes['id'], config('site.superAdmin_ids', []));
    }

    /**
     * 检查用户名是否存在
     * @param $username
     * @param $ignore_id
     * @return bool
     */
    public static function checkUsernameIsUnique($username, $ignore_id = 0)
    {
        return self::query()->where('username', $username)->where('id', '<>', $ignore_id)->exists();
    }
}
