<?php

namespace App\Repositories\Transformers\Course;

use App\Repositories\Enums\Course\CourseRecEnum;
use App\Repositories\Enums\Course\CourseTypeEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Course\Chapter;
use App\Repositories\Models\Course\Collect;
use Carbon\Carbon;
use League\Fractal\TransformerAbstract;
use App\Repositories\Models\Course\Course;

/**
 * Class CourseTransformer.
 *
 * @package namespace App\Repositories\Transformers;
 */
class CourseTransformer extends TransformerAbstract
{
    /**
     * Transform the Course entity.
     *
     * @param \App\Repositories\Models\Course\Course $model
     *
     * @return array
     */
    public function transform(Course $model)
    {
        if (isApiModule()) {
            return $this->apiTransform($model);
        }

        if (request()->has('id')) {
            return [
                'id' => (int)$model->id,
                'title' => $model->title,
                'subscribe' => $model->subscribe,
                'category' => $model->category,
                'type' => $model->type,
                'type_text' => CourseTypeEnum::getDescription($model->type),
                'labels' => $model->labels,
                'slug' => $model->slug,
                'thumb_resource' => $model->thumb_resource,
                'short_description' => $model->short_description,
                'description' => $model->description,
                'published_at' => $model->published_at,
                'user_count' => $model->user_count,
                'settings' => $model->settings,
                'video_nums' => $model->video_nums,
                'is_rec' => $model->is_rec,
                'status' => $model->status,
                'is_rec_text' => CourseRecEnum::getDescription($model->is_rec),
                'teacher' => $model->teacher,
                'directories' => Chapter::byCourseIdGetDirectory($model->id),
                'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT)
            ];
        }

        return [
            'id' => (int)$model->id,
            'title' => $model->title,
            'category' => $model->category,
            'type' => $model->type,
            'type_text' => CourseTypeEnum::getDescription($model->type),
            'labels' => $model->labels,
            'slug' => $model->slug,
            'thumb' => $model->thumb,
            'thumb_resource' => $model->thumb_resource,
            'short_description' => $model->short_description,
            'description' => $model->description,
            'published_at' => $model->published_at,
            'is_rec' => $model->is_rec,
            'is_rec_text' => CourseRecEnum::getDescription($model->is_rec),
            'user_count' => $model->user_count,
            'settings' => $model->settings,
            'sort' => $model->sort,
            'video_nums' => $model->video_nums,
            'teacher' => $model->teacher,
            'status' => $model->status,
            'status_test' => ModelStatusEnum::getDescription($model->status),
            'created_at' => $model->created_at->format(Carbon::DEFAULT_TO_STRING_FORMAT),
            'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT)
        ];
    }

    public function apiTransform(Course $model)
    {
        if (request()->has('id')) {
            return [
                'id' => (int)$model->id,
                'title' => $model->title,
                'subscribe' => $model->subscribe,
                'category' => $model->category,
                'type' => $model->type,
                'type_text' => CourseTypeEnum::getDescription($model->type),
                'labels' => $model->labels,
                'slug' => $model->slug,
                'thumb_resource' => $model->thumb_resource,
                'short_description' => $model->short_description,
                'description' => $model->description,
                'published_at' => $model->published_at,
                'user_count' => $model->user_count,
                'settings' => $model->settings,
                'video_nums' => $model->video_nums,
                'teacher' => $model->teacher,
                'is_collection_status' => Collect::isCollect($model->id),
                'directories' => Chapter::byCourseIdGetDirectory($model->id),
                'is_rec' => $model->is_rec,
                'is_rec_text' => CourseRecEnum::getDescription($model->is_rec),
                'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT)
            ];
        }
        return [
            'id' => (int)$model->id,
            'title' => $model->title,
            'category' => $model->category,
            'type' => $model->type,
            'type_text' => CourseTypeEnum::getDescription($model->type),
            'labels' => $model->labels,
            'slug' => $model->slug,
            'thumb_resource' => $model->thumb_resource,
            'short_description' => $model->short_description,
//                'description' => $model->description,
            'published_at' => $model->published_at,
//                'is_rec' => $model->is_rec,
            'user_count' => $model->user_count,
            'subscribe' => $model->subscribe,
//                'settings' => $model->settings,
            'video_nums' => $model->video_nums,
            'is_rec' => $model->is_rec,
            'is_rec_text' => CourseRecEnum::getDescription($model->is_rec),
            'teacher' => $model->teacher,
            'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT)
        ];

    }
}
