<?php

namespace App\Repositories\Transformers\School;

use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Transformers\BaseTransformer;
use Carbon\Carbon;

/**
 * Class LessonScheduleTransformer.
 *
 * @package namespace App\Repositories\Transformers\School;
 */
class LessonScheduleTransformer extends BaseTransformer
{
    /**
     * Transform the LessonSchedule entity.
     *
     * @param \App\Repositories\Models\School\LessonSchedule $model
     *
     * @return array
     */
    public function lists($model)
    {
        return [
            'id' => (int)$model->id,

            'day' => $model->day,
            'week' => $model->week,
            'week_index' => $model->week_index,
            'time_id' => $model->time,

            'teach_title' => $model->teach_title,
            'lesson' => $model->lesson,
            'room' => $model->room,
            'grade' => $model->grade,
            'teacher' => $model->teacher,
            'group' => $model->group,
            'group_name' => $model->group_name,

            'student_nums' => $model->student_nums,

            'migrate_id' => $model->migrate_id,
            'status' => $model->status,
            'created_at' => $model->created_at->format(Carbon::DEFAULT_TO_STRING_FORMAT),
        ];
    }

    public function detail($model)
    {
        return [
            'id' => (int)$model->id,

            'day' => $model->day,
            'week' => $model->week,
            'week_index' => $model->week_index,
            'time_id' => $model->time,

            'teach_title' => $model->teach_title,
            'lesson' => $model->lesson,
            'grade' => $model->grade,
            'teacher' => $model->teacher,
            'group' => $model->group,
            'group_name' => $model->group_name,
            'class_hour' => $model->class_hour,

            'student_nums' => $model->student_nums,
            'migrate_id' => $model->migrate_id,

            'lesson_teacher_id' => $model->lesson_teacher_id,
            'term_id' => $model->term_id,
            'teach_type' => $model->teach_type,
            'teach_type_name' => TeachTypeEnum::getDescription($model->teach_type),
            'teach_teacher_ids' => $model->teach_teacher_ids,

            'status' => $model->status,
            'created_at' => $model->created_at->format(Carbon::DEFAULT_TO_STRING_FORMAT),
            'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT),
        ];
    }
}
