<?php

namespace App\Services\Base;

use App\Contracts\Repositories\Base\DictDetailRepository;
use App\Repositories\Criteria\Base\DictDetailCriteria;
use App\Repositories\Eloquent\Base\DictDetailRepositoryEloquent;
use App\Repositories\Presenters\Base\DictDetailPresenter;
use Illuminate\Http\Request;

class DictDetailService
{
    /**
     * @var DictDetailRepositoryEloquent
     */
    private $dictDetailRepository;

    /**
     * DictDetailService constructor.
     *
     * @param DictDetailRepositoryEloquent $dictDetailRepositoryEloquent
     */
    public function __construct(DictDetailRepositoryEloquent $dictDetailRepositoryEloquent)
    {
        $this->dictDetailRepository = $dictDetailRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->dictDetailRepository->pushCriteria(new DictDetailCriteria($request));
        $this->dictDetailRepository->setPresenter(DictDetailPresenter::class);

        return $this->dictDetailRepository->searchDictDetailsByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->dictDetailRepository->setPresenter(DictDetailPresenter::class);
        return $this->dictDetailRepository->searchDictDetailBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $dictDetail = $this->dictDetailRepository->create($data);
        return $dictDetail;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $dictDetail = $this->dictDetailRepository->update($data, $data['id']);
        return $dictDetail;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->dictDetailRepository->delete($id);
    }

    /**
     * 检测值是否重复
     * @param $dict_id
     * @param $value
     * @return mixed
     */
    public function handleCheckValueIsUnique($dict_id, $value)
    {
        return $this->dictDetailRepository->checkValueIsUnique($dict_id, $value);
    }
}
