<?php

namespace App\Services\Base;

use App\Contracts\Repositories\Base\PermissionRepository;
use App\Repositories\Criteria\Base\PermissionCriteria;
use App\Repositories\Eloquent\Base\PermissionRepositoryEloquent;
use App\Repositories\Presenters\Base\PermissionPresenter;
use Illuminate\Http\Request;

class PermissionService
{
    /**
     * @var PermissionRepositoryEloquent
     */
    private $permissionRepository;

    /**
     * PermissionService constructor.
     *
     * @param PermissionRepositoryEloquent $permissionRepositoryEloquent
     */
    public function __construct(PermissionRepositoryEloquent $permissionRepositoryEloquent)
    {
        $this->permissionRepository = $permissionRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->permissionRepository->pushCriteria(new PermissionCriteria($request));
        $this->permissionRepository->setPresenter(PermissionPresenter::class);

        return $this->permissionRepository->searchPermissionsByPage();
    }

    public function handleListNoPage(Request $request)
    {
        $this->permissionRepository->pushCriteria(new PermissionCriteria($request));
        $this->permissionRepository->setPresenter(PermissionPresenter::class);

        return $this->permissionRepository->searchPermissions();
    }


    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->permissionRepository->setPresenter(PermissionPresenter::class);
        return $this->permissionRepository->searchPermissionBy($id);
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore(Request $request)
    {
        $permission = $this->permissionRepository->create($request->all());
        return $permission;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate(Request $request)
    {
        $permission = $this->permissionRepository->update($request->all(), $request->get('id'));
        return $permission;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->permissionRepository->delete($id);
    }
}
