<?php

namespace App\Services\Course;

use App\Contracts\Repositories\Course\CollectRepository;
use App\Repositories\Criteria\Course\CollectCriteria;
use App\Repositories\Eloquent\Course\CollectRepositoryEloquent;
use App\Repositories\Presenters\Course\CollectPresenter;
use Illuminate\Http\Request;

class CollectService
{
    /**
     * @var CollectRepositoryEloquent
     */
    private $repository;

    /**
     * CollectService constructor.
     *
     * @param CollectRepositoryEloquent $collectRepositoryEloquent
     */
    public function __construct(CollectRepositoryEloquent $repository)
    {
        $this->repository = $repository;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->repository->pushCriteria(new CollectCriteria($request));
        $this->repository->setPresenter(CollectPresenter::class);

        return $this->repository->searchListsPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->repository->setPresenter(CollectPresenter::class);
        return $this->repository->searchBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $collect = $this->repository->create($data);
        return $collect;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $collect = $this->repository->update($data, $data['id']);
        return $collect;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->repository->delete($id);
    }

    /**
     * 选项
     * @param Request $request
     * @return \Illuminate\Contracts\Pagination\LengthAwarePaginator|\Illuminate\Support\Collection|mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleSelectOptions(Request $request)
    {
        $this->repository->pushCriteria(new CollectCriteria($request));
        return $this->repository->all(['id', 'name']);
    }

    /**
     * 批量删除
     * @param $ids
     * @return mixed
     */
    public function handleBatchDelete($ids)
    {
        return $this->repository->whereIn('id', $ids)->delete();
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleAll(Request $request)
    {
        $this->repository->pushCriteria(new CollectCriteria($request));
        $this->repository->setPresenter(CollectPresenter::class);

        return $this->repository->get();
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleIds(Request $request)
    {
        $this->repository->pushCriteria(new CollectCriteria($request));
        return $this->repository->pluck('id');
    }
}
