<?php

namespace App\Services\Course;

use App\Contracts\Repositories\Course\SubscribeRepository;
use App\Repositories\Criteria\Course\SubscribeCriteria;
use App\Repositories\Eloquent\Course\SubscribeRepositoryEloquent;
use App\Repositories\Presenters\Course\SubscribePresenter;
use Illuminate\Http\Request;

class SubscribeService
{
    /**
     * @var SubscribeRepositoryEloquent
     */
    private $subscribeRepository;

    /**
     * SubscribeService constructor.
     *
     * @param SubscribeRepositoryEloquent $subscribeRepositoryEloquent
     */
    public function __construct(SubscribeRepositoryEloquent $subscribeRepositoryEloquent)
    {
        $this->subscribeRepository = $subscribeRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->subscribeRepository->pushCriteria(new SubscribeCriteria($request));
        $this->subscribeRepository->setPresenter(SubscribePresenter::class);

        return $this->subscribeRepository->searchSubscribesByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->subscribeRepository->setPresenter(SubscribePresenter::class);
        return $this->subscribeRepository->searchSubscribeBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $subscribe = $this->subscribeRepository->create($data);
        return $subscribe;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $subscribe = $this->subscribeRepository->update($data, $data['id']);
        return $subscribe;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->subscribeRepository->delete($id);
    }
}
