<?php

namespace App\Services\Course;

use App\Contracts\Repositories\Course\VideoRepository;
use App\Repositories\Criteria\Course\VideoCriteria;
use App\Repositories\Eloquent\Course\VideoRepositoryEloquent;
use App\Repositories\Presenters\Course\VideoPresenter;
use Illuminate\Http\Request;

class VideoService
{
    /**
     * @var VideoRepositoryEloquent
     */
    private $videoRepository;

    /**
     * VideoService constructor.
     *
     * @param VideoRepositoryEloquent $videoRepositoryEloquent
     */
    public function __construct(VideoRepositoryEloquent $videoRepositoryEloquent)
    {
        $this->videoRepository = $videoRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->videoRepository->pushCriteria(new VideoCriteria($request));
        $this->videoRepository->setPresenter(VideoPresenter::class);

        return $this->videoRepository->searchVideosByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->videoRepository->setPresenter(VideoPresenter::class);
        return $this->videoRepository->searchVideoBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $video = $this->videoRepository->create($data);
        return $video;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $video = $this->videoRepository->update($data, $data['id']);
        return $video;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->videoRepository->delete($id);
    }

    /**
     * 选项
     * @param Request $request
     * @return \Illuminate\Contracts\Pagination\LengthAwarePaginator|\Illuminate\Support\Collection|mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleSelectOptions(Request $request)
    {
        $this->videoRepository->pushCriteria(new VideoCriteria($request));
        return $this->videoRepository->all(['id', 'title']);
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleAll(Request $request)
    {
        $this->videoRepository->pushCriteria(new VideoCriteria($request));
        $this->videoRepository->setPresenter(VideoPresenter::class);

        return $this->videoRepository->get();
    }

    /**
     * 批量删除
     * @param $ids
     * @return mixed
     */
    public function handleBatchDelete($ids)
    {
        return $this->videoRepository->whereIn('id', $ids)->delete();
    }
}
