<?php

namespace App\Services\Info;

use App\Contracts\Repositories\Info\InformationRepository;
use App\Repositories\Criteria\Info\InformationCriteria;
use App\Repositories\Eloquent\Info\InformationRepositoryEloquent;
use App\Repositories\Presenters\Info\InformationPresenter;
use Illuminate\Http\Request;

class InformationService
{
    /**
     * @var InformationRepositoryEloquent
     */
    private $informationRepository;

    /**
     * InformationService constructor.
     *
     * @param InformationRepositoryEloquent $informationRepositoryEloquent
     */
    public function __construct(InformationRepositoryEloquent $informationRepositoryEloquent)
    {
        $this->informationRepository = $informationRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->informationRepository->pushCriteria(new InformationCriteria($request));
        $this->informationRepository->setPresenter(InformationPresenter::class);

        return $this->informationRepository->searchInformationsByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->informationRepository->setPresenter(InformationPresenter::class);
        return $this->informationRepository->searchInformationBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $information = $this->informationRepository->create($data);
        return $information;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $information = $this->informationRepository->update($data, $data['id']);
        return $information;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->informationRepository->delete($id);
    }
}
