<?php

namespace App\Services\Info;

use App\Repositories\Criteria\Info\InformationTypeCriteria;
use App\Repositories\Eloquent\Info\InformationTypeRepositoryEloquent;
use App\Repositories\Presenters\Info\InformationTypePresenter;
use Illuminate\Http\Request;

class InformationTypeService
{
    /**
     * @var InformationTypeRepositoryEloquent
     */
    private $informationTypeRepository;

    /**
     * InformationTypeService constructor.
     *
     * @param InformationTypeRepositoryEloquent $informationTypeRepositoryEloquent
     */
    public function __construct(InformationTypeRepositoryEloquent $informationTypeRepositoryEloquent)
    {
        $this->informationTypeRepository = $informationTypeRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->informationTypeRepository->pushCriteria(new InformationTypeCriteria($request));
        $this->informationTypeRepository->setPresenter(InformationTypePresenter::class);

        return $this->informationTypeRepository->searchInformationTypesByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->informationTypeRepository->setPresenter(InformationTypePresenter::class);
        return $this->informationTypeRepository->searchInformationTypeBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $informationType = $this->informationTypeRepository->create($data);
        return $informationType;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $informationType = $this->informationTypeRepository->update($data, $data['id']);
        return $informationType;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->informationTypeRepository->delete($id);
    }
}
