<?php

namespace App\Services\Info;

use App\Contracts\Repositories\Info\NoticeRepository;
use App\Repositories\Criteria\Info\NoticeCriteria;
use App\Repositories\Eloquent\Info\NoticeRepositoryEloquent;
use App\Repositories\Presenters\Info\NoticePresenter;
use Illuminate\Http\Request;

class NoticeService
{
    /**
     * @var NoticeRepositoryEloquent
     */
    private $noticeRepository;

    /**
     * NoticeService constructor.
     *
     * @param NoticeRepositoryEloquent $noticeRepositoryEloquent
     */
    public function __construct(NoticeRepositoryEloquent $noticeRepositoryEloquent)
    {
        $this->noticeRepository = $noticeRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->noticeRepository->pushCriteria(new NoticeCriteria($request));
        $this->noticeRepository->setPresenter(NoticePresenter::class);

        return $this->noticeRepository->searchNoticesByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->noticeRepository->setPresenter(NoticePresenter::class);
        return $this->noticeRepository->searchNoticeBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $notice = $this->noticeRepository->create($data);
        return $notice;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $notice = $this->noticeRepository->update($data, $data['id']);
        return $notice;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->noticeRepository->delete($id);
    }
}
