<?php

namespace App\Services\School;

use App\Contracts\Repositories\School\GradeRepository;
use App\Repositories\Criteria\School\GradeCriteria;
use App\Repositories\Eloquent\School\GradeRepositoryEloquent;
use App\Repositories\Presenters\School\GradePresenter;
use Illuminate\Http\Request;

class GradeService
{
    /**
     * @var GradeRepositoryEloquent
     */
    private $gradeRepository;

    /**
     * GradeService constructor.
     *
     * @param GradeRepositoryEloquent $gradeRepositoryEloquent
     */
    public function __construct(GradeRepositoryEloquent $gradeRepositoryEloquent)
    {
        $this->gradeRepository = $gradeRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->gradeRepository->pushCriteria(new GradeCriteria($request));
        $this->gradeRepository->setPresenter(GradePresenter::class);

        return $this->gradeRepository->searchGradesByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->gradeRepository->setPresenter(GradePresenter::class);
        return $this->gradeRepository->searchGradeBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $grade = $this->gradeRepository->create($data);
        return $grade;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $grade = $this->gradeRepository->update($data, $data['id']);
        return $grade;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->gradeRepository->delete($id);
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleAll(Request $request)
    {
        $this->gradeRepository->pushCriteria(new GradeCriteria($request));
        $this->gradeRepository->setPresenter(GradePresenter::class);

        return $this->gradeRepository->get();
    }

    /**
     * 选项
     * @param Request $request
     * @return \Illuminate\Contracts\Pagination\LengthAwarePaginator|\Illuminate\Support\Collection|mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleSelectOptions(Request $request)
    {
        $this->gradeRepository->pushCriteria(new GradeCriteria($request));
        return $this->gradeRepository->all(['id', 'name']);
    }

    /**
     * 批量删除
     * @param $ids
     * @return mixed
     */
    public function handleBatchDelete($ids)
    {
        return $this->gradeRepository->whereIn('id', $ids)->delete();
    }
}
