<?php

namespace App\Services\School;

use App\Repositories\Criteria\School\TeacherCriteria;
use App\Repositories\Eloquent\School\TeacherRepositoryEloquent;
use App\Repositories\Presenters\School\TeacherPresenter;
use Illuminate\Http\Request;

class TeacherService
{
    /**
     * @var TeacherRepositoryEloquent
     */
    private $teacherRepository;

    /**
     * TeacherService constructor.
     *
     * @param TeacherRepositoryEloquent $teacherRepositoryEloquent
     */
    public function __construct(TeacherRepositoryEloquent $teacherRepositoryEloquent)
    {
        $this->teacherRepository = $teacherRepositoryEloquent;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleList(Request $request)
    {
        $this->teacherRepository->pushCriteria(new TeacherCriteria($request));
        $this->teacherRepository->setPresenter(TeacherPresenter::class);

        return $this->teacherRepository->searchTeachersByPage();
    }

    /**
     * @param $id
     *
     * @return \Illuminate\Database\Eloquent\Model
     */
    public function handleProfile($id)
    {
        $this->teacherRepository->setPresenter(TeacherPresenter::class);
        return $this->teacherRepository->searchTeacherBy($id);
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleStore($data)
    {
        $teacher = $this->teacherRepository->create($data);
        return $teacher;
    }

    /**
     * @param array $data
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleUpdate($data)
    {
        $teacher = $this->teacherRepository->update($data, $data['id']);
        return $teacher;
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function handleDelete($id)
    {
        return $this->teacherRepository->delete($id);
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleAll(Request $request)
    {
        $this->teacherRepository->pushCriteria(new TeacherCriteria($request));
        $this->teacherRepository->setPresenter(TeacherPresenter::class);

        return $this->teacherRepository->get();
    }

    /**
     * @param Request $request
     *
     * @return mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleIds(Request $request)
    {
        $this->teacherRepository->pushCriteria(new TeacherCriteria($request));
        return $this->teacherRepository->pluck('id');
    }

    /**
     * 选项
     * @param Request $request
     * @return \Illuminate\Contracts\Pagination\LengthAwarePaginator|\Illuminate\Support\Collection|mixed
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function handleSelectOptions(Request $request)
    {
        $this->teacherRepository->pushCriteria(new TeacherCriteria($request));
        return $this->teacherRepository->all(['id', 'name', 'account']);
    }

    /**
     * 批量删除
     * @param $ids
     * @return mixed
     */
    public function handleBatchDelete($ids)
    {
        return $this->teacherRepository->whereIn('id', $ids)->delete();
    }
}
