<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It is a breeze. Simply tell Lumen the URIs it should respond to
| and give it the Closure to call when that URI is requested.
|
*/

/**
 * 基础业务模块
 */
Route::group(['namespace' => 'Base'], function () {
    //登录
    Route::post('/auth/login', 'AuthController@login');
    //微信小程序登录
//    Route::post('/auth/mini-program-login', 'AuthController@miniProgramLogin');
//    Route::post('/auth/mini-program-mobile-login', 'AuthController@miniProgramMobileLogin');
//    Route::post('/auth/test-mobile-login', 'AuthController@testMobile');
//    Route::post('/auth/send-validation-code', 'AuthController@sendValidationCode');
//    Route::post('/auth/retrieve-password', 'AuthController@retrievePassword');
//    Route::post('/auth/find-email', 'AuthController@findEmail');

    //配置文件
    Route::post('base/settings/configs', 'SettingController@configs');
    Route::post('base/dicts/configs', 'DictController@configs');
    Route::get('base/dicts/config', 'DictController@config');

    //上传文件
    Route::post('/common/upload', 'ResourceController@upload');

    //枚举
    Route::get('/common/enums', 'CommonController@enums');
    Route::get('/common/clear', 'CommonController@clear');

    Route::group([
        'middleware' => ['auth:admins', 'auth.role:admin'],
        'prefix' => 'base'
    ], function () {
        Route::get('/auth/me', 'AuthController@me');
        Route::put('/auth/me', 'AuthController@update');
        Route::get('/auth/logout', 'AuthController@logout');
        Route::post('/auth/reset-password', 'AuthController@resetPassword');
//            Route::post('/auth/refresh-token', 'AuthController@refreshToken');
        Route::post('/auth/validate-password', 'AuthController@validatePassword');
//        Route::post('/auth/bind-wechat', 'AuthController@bindWechat');
//        Route::get('/auth/unbind-wechat', 'AuthController@unbindWechat');
        Route::post('/auth/mini-bind-mobile', 'AuthController@miniBindMobile');
        Route::post('/auth/update-password', 'AuthController@updatePassword');
        Route::post('/auth/update-info', 'AuthController@updateInfo');
        Route::post('/auth/mobile/send-validate-code', 'AuthController@sendValidateCode');
        Route::post('/auth/mobile', 'AuthController@updateMobile');


        //部门管理
        Route::get('departments', 'DepartmentController@index');
        Route::get('department', 'DepartmentController@show');
        Route::post('department', 'DepartmentController@store');
        Route::put('department', 'DepartmentController@update');
        Route::delete('department', 'DepartmentController@destroy');
        Route::post('department/delete', 'DepartmentController@batchDelete');
        Route::get('department/tree', 'DepartmentController@tree');
        Route::get('department/select-options', 'DepartmentController@selectOptions');

        //管理员
        Route::get('/admins', 'AdminController@index');
        Route::get('admin', 'AdminController@show');
        Route::post('admin', 'AdminController@store');
        Route::put('admin', 'AdminController@update');
        Route::delete('admin', 'AdminController@destroy');
        Route::post('admin/authorization', 'AdminController@authorization');
        Route::get('admin/select-options', 'AdminController@selectOptions');
        Route::post('admin/change-password', 'AdminController@changePassword');
        Route::post('admin/import', 'AdminController@import');
        Route::post('/admin/batch-update-status', 'AdminController@batchUpdateStatus');

        //角色
        Route::get('/roles', 'RoleController@index');
        Route::post('/role', 'RoleController@store');
        Route::get('/role', 'RoleController@show');
        Route::put('/role', 'RoleController@update');
        Route::delete('/role', 'RoleController@destroy');
        Route::post('/role/save-menus', 'RoleController@saveMenusPermissions');
        Route::post('/role/save-data-permissions', 'RoleController@saveDataPermissions');
        Route::post('/role/save-apis-permissions', 'RoleController@saveApisPermissions');
        Route::get('/role/permissions', 'RoleController@getRolePermissions');
        Route::get('/role/select-options', 'RoleController@selectOptions');

        //菜单管理
        Route::get('/menus', 'MenuController@index');
        Route::post('/menu', 'MenuController@store');
        Route::get('/menu', 'MenuController@show');
        Route::put('/menu', 'MenuController@update');
        Route::delete('/menu', 'MenuController@destroy');
        Route::get('/menu/icons', 'MenuController@icons');
        Route::get('/menu/my-menus', 'MenuController@myMenus');

        //日志记录
        Route::get('/logs', 'LogController@index');
        Route::get('/log', 'LogController@show');
        Route::post('/log/app-upload-log', 'LogController@appUploadLog');

        //轮播图管理
        Route::get('/banners', 'BannerController@index');
        Route::get('/banner/list', 'BannerController@lists');
        Route::post('/banner', 'BannerController@store');
        Route::get('/banner', 'BannerController@show');
        Route::put('/banner', 'BannerController@update');
        Route::delete('/banner', 'BannerController@destroy');

        //字典管理
        Route::get('/dicts', 'DictController@index');
        Route::post('/dict', 'DictController@store');
        Route::get('/dict', 'DictController@show');
        Route::put('/dict', 'DictController@update');
        Route::delete('/dict', 'DictController@destroy');

        Route::get('/dict-details', 'DictDetailController@index');
        Route::post('/dict-detail', 'DictDetailController@store');
        Route::get('/dict-detail', 'DictController@show');
        Route::put('/dict-detail', 'DictDetailController@update');
        Route::delete('/dict-detail', 'DictDetailController@destroy');

        //分类管理
        Route::get('categories', 'CategorySettingController@index');
        Route::post('category', 'CategorySettingController@storeCategory');
        Route::post('category-option', 'CategorySettingController@store');
        Route::get('category/{id}', 'CategorySettingController@show');
        Route::put('category/{id}', 'CategorySettingController@update');
        Route::delete('category/{id}', 'CategorySettingController@destroy');
        Route::post('category-delete', 'CategorySettingController@delete');
        Route::get('category-select-options', 'CategorySettingController@selectOptions');

        //配置管理
        Route::get('/settings', 'SettingController@index');
        Route::post('/setting', 'SettingController@store');
        Route::get('/setting', 'SettingController@show');
        Route::put('/setting', 'SettingController@update');
        Route::delete('/setting', 'SettingController@destroy');
        Route::post('/setting/save', 'SettingController@save');

        //公司管理
        Route::get('/companies', 'CompanyController@index');
        Route::post('/company', 'CompanyController@store');
        Route::get('/company', 'CompanyController@show');
        Route::put('/company', 'CompanyController@update');
        Route::delete('/company', 'CompanyController@destroy');
        Route::get('/company/select-options', 'CompanyController@selectOptions');

        //API权限列表
        Route::get('/permissions', 'PermissionController@index');

        //资源管理
        Route::post('/resource/upload', 'ResourceController@upload');
        Route::post('/resource/download', 'ResourceController@download');
        Route::post('/resource/base64-to-img', 'ResourceController@base64ToImg');

        //任务管理
        Route::get('/tasks', 'TaskController@index');
    });

});

//高校公用模块
Route::group([
    'middleware' => ['auth:admins', 'auth.role:admin'],
    'prefix' => 'school',
    'namespace' => 'School'
], function () {
//    //学期管理
//    Route::get('term', 'TermsController@index');
//    Route::post('term', 'TermsController@store');
//    Route::get('term/info/{id}', 'TermsController@show');
//    Route::get('term/pause', 'TermsController@pause');
//    Route::put('term/{id}', 'TermsController@update');
//    Route::delete('term/{id}', 'TermsController@destroy');
//    Route::post('term-delete', 'TermsController@delete');
//    Route::get('term-select-options', 'TermsController@selectOptions');
//
//    //时间段管理
//    Route::get('time', 'TimesController@index');
//    Route::post('time', 'TimesController@store');
//    Route::get('time/info/{id}', 'TimesController@show');
//    Route::get('time/pause', 'TimesController@pause');
//    Route::put('time/{id}', 'TimesController@update');
//    Route::delete('time/{id}', 'TimesController@destroy');
//    Route::post('time-delete', 'TimesController@delete');
//    Route::get('time-select-options', 'TimesController@selectOptions');
//
//    //班级管理
    Route::get('grades', 'GradesController@index');
    Route::post('grade', 'GradesController@store');
    Route::get('grade', 'GradesController@show');
    Route::put('grade', 'GradesController@update');
    Route::delete('grade', 'GradesController@destroy');
    Route::post('grade/batch-delete', 'GradesController@batchDelete');
    Route::get('grade/select-options', 'GradesController@selectOptions');
//
//    //老师管理
    Route::get('teachers', 'TeachersController@index');
    Route::post('teacher', 'TeachersController@store');
    Route::get('teacher', 'TeachersController@show');
    Route::put('teacher', 'TeachersController@update');
    Route::delete('teacher', 'TeachersController@destroy');
    Route::post('teacher/delete', 'TeachersController@batchDelete');
    Route::post('teacher/import', 'TeachersController@importTeachers');
    Route::post('teacher/export', 'TeachersController@exportTeachers');
    Route::get('teacher/select-options', 'TeachersController@selectOptions');
    Route::post('teacher/update-status', 'TeachersController@updateStatus');
    Route::post('teacher/change-password', 'TeachersController@changePassword');
//
//    //学生管理
    Route::get('students', 'StudentsController@index');
    Route::post('student', 'StudentsController@store');
    Route::get('student', 'StudentsController@show');
    Route::put('student', 'StudentsController@update');
    Route::delete('student', 'StudentsController@destroy');
    Route::post('student/delete', 'StudentsController@batchDelete');
    Route::post('student/import', 'StudentsController@importStudents');
    Route::post('student/export', 'StudentsController@exportStudents');
    Route::get('student/select-options', 'StudentsController@selectOptions');
    Route::post('student/update-status', 'StudentsController@updateStatus');
    Route::post('student/change-password', 'StudentsController@changePassword');
});

/**
 * 试卷
 */
//Route::group([
//    'middleware' => ['auth:admins', 'auth.role:admin'],
//    'prefix' => 'exam',
//    'namespace' => 'Exam'
//], function () {
//    Route::get('home', 'HomeController@index');
//
//
//    //任务管理
//    Route::get('/paper', 'PapersController@index');
//    Route::post('/paper', 'PapersController@store');
//    Route::get('/paper/info/{id}', 'PapersController@show');
//    Route::put('/paper/info/{id}', 'PapersController@update');
//    Route::delete('/paper/info/{id}', 'PapersController@destroy');
//    Route::post('/paper/delete', 'PapersController@delete');
//    Route::get('/paper/select-options', 'PapersController@selectOptions');
//    Route::get('/paper/pause', 'PapersController@pause');
//
//    //试题
//    Route::get('/topic', 'TopicsController@index');
//    Route::post('/topic', 'TopicsController@store');
//    Route::get('/topic/info/{id}', 'TopicsController@show');
//    Route::put('/topic/info/{id}', 'TopicsController@update');
//    Route::delete('/topic/info/{id}', 'TopicsController@destroy');
//    Route::post('/topic/delete', 'TopicsController@delete');
//    Route::get('/topic/select-options', 'TopicsController@selectOptions');
//    Route::get('/topic/pause', 'TopicsController@pause');
//
//    //考试
//    Route::get('/paper-result', 'PaperResultsController@index');
//    Route::post('/paper-result/allot', 'PaperResultsController@allot');
//    Route::post('/paper-result/answer', 'PaperResultsController@answer');
//    Route::post('/paper-result', 'PaperResultsController@store');
//    Route::get('/paper-result/info/{id}', 'PaperResultsController@show');
//    Route::put('/paper-result/info/{id}', 'PaperResultsController@update');
//    Route::delete('/paper-result/info/{id}', 'PaperResultsController@destroy');
//    Route::post('/paper-result/delete', 'PaperResultsController@delete');
//    Route::get('/paper-result/select-options', 'PaperResultsController@selectOptions');
//    Route::get('/paper-result/pause', 'PaperResultsController@pause');
//
//});

/**
 * 通知公告
 */
Route::group([
    'middleware' => ['auth:admins', 'auth.role:admin'],
    'prefix' => 'info',
    'namespace' => 'Info'
], function () {
    //新闻管理
    Route::get('/news', 'NewsController@index');
    Route::post('/new', 'NewsController@store');
    Route::get('/new', 'NewsController@show');
    Route::put('/new', 'NewsController@update');
    Route::delete('/new', 'NewsController@destroy');

    //通知公告
    Route::get('/notices', 'NoticeController@index');
    Route::post('/notice', 'NoticeController@store');
    Route::get('/notice', 'NoticeController@show');
    Route::put('/notice', 'NoticeController@update');
    Route::delete('/notice', 'NoticeController@destroy');

    //资讯类型
    Route::get('/info_types', 'InformationTypeController@index');
    Route::post('/info_type', 'InformationTypeController@store');
    Route::get('/info_type', 'InformationTypeController@show');
    Route::put('/info_type', 'InformationTypeController@update');
    Route::delete('/info_type', 'InformationTypeController@destroy');

    //资讯内容
    Route::get('/infos', 'InformationController@index');
    Route::get('/info', 'InformationController@show');
    Route::post('/info', 'InformationController@store');
    Route::put('/info', 'InformationController@update');
    Route::delete('/info', 'InformationController@destroy');
});

//课程
Route::group([
    'prefix' => 'course',
    'namespace' => 'Course',
    'middleware' => ['auth:admins', 'auth.role:admin']
], function () {
    //    首页
    Route::get('/home', 'HomeController@index');

    //分类
    Route::get('categories', 'CategoryController@index');
    Route::post('category', 'CategoryController@store');
    Route::get('category', 'CategoryController@show');
    Route::put('category', 'CategoryController@update');
    Route::delete('category', 'CategoryController@destroy');
    Route::post('category/batch-delete', 'CategoryController@batchDelete');
    Route::get('category/tree', 'CategoryController@tree');
    Route::get('category/select-options', 'CategoryController@selectOptions');

    //课程
    Route::get('courses', 'CourseController@index');
    Route::post('course', 'CourseController@store');
    Route::get('course', 'CourseController@show');
    Route::put('course', 'CourseController@update');
    Route::delete('course', 'CourseController@destroy');
    Route::post('course/batch-delete', 'CourseController@batchDelete');
    Route::get('course/select-options', 'CourseController@selectOptions');

    //章节
    Route::get('chapters', 'ChapterController@index');
    Route::post('chapter', 'ChapterController@store');
    Route::put('chapter', 'ChapterController@update');
    Route::delete('chapter', 'ChapterController@destroy');

    //视频
    Route::get('/videos', 'VideoController@index');
    Route::post('/video', 'VideoController@store');
    Route::get('/video', 'VideoController@show');
    Route::put('video', 'VideoController@update');
    Route::delete('video', 'VideoController@destroy');

    //附件
    Route::get('/attachs', 'AttachController@index');
    Route::post('/attach', 'AttachController@store');
    Route::put('attach', 'AttachController@update');
    Route::delete('attach', 'AttachController@destroy');

    //评论
    Route::get('/comments', 'CommentController@index');
//    Route::post('/comment', 'CommentController@store');
    Route::get('/comment', 'CommentController@show');
//    Route::put('comment', 'CommentController@update');
    Route::delete('comment', 'CommentController@destroy');

    //订阅管理
    Route::get('/subscribes', 'SubscribeController@index');
    Route::get('/subscribe', 'SubscribeController@show');
    Route::delete('subscribe', 'SubscribeController@destroy');


    Route::get('/nodes', 'NodeController@index');
    Route::get('/node', 'NodeController@show');
    Route::delete('/node', 'NodeController@destroy');
});


//附件下载
//Route::get('/view/attach-download/{id}', 'Course\AttachController@download');

Route::get('/', function () {
    if (config('app.debug')) {
        return \Illuminate\Support\Facades\Response::success([
            'name' => config('app.name'),
            'version' => app()->version(),
            'ip' => getClientIp()
        ]);
    }

    return 'hello word!';
});

//开发环境接口
Route::group(['prefix' => 'develop'], function () {
    //响应状态
//    Route::get('/http-status', 'DevelopController@httpStatus');
    Route::get('/t', 'ExampleController@test');
    Route::get('/init', 'ExampleController@init');
});
